import logging
import os

from sqlalchemy import create_engine, Column, String, Text
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

base = declarative_base()


class Articles(base):
    __tablename__ = "articles"
    link = Column(String(100), primary_key=True)
    tittle = Column(Text)
    content = Column(Text)
    status = Column(String(100))


def apply_schema(file_path: str = os.path.join(os.path.abspath(os.getcwd()), "tabayyun.db")):
    logging.info("Set SQLite as the DB engine")
    engine = create_engine("sqlite:///" + file_path)
    Session = sessionmaker(bind=engine)
    session = Session()
    base.metadata.create_all(engine)


if __name__ == "__main__":
    apply_schema()



import concurrent.futures
import logging
import re
from sqlite3 import IntegrityError

import pandas as pd
import requests
from bs4 import BeautifulSoup
from sqlalchemy import create_engine
from sqlalchemy.exc import IntegrityError

result = []


def crawl(page: str):
    html = requests.get(page)
    bs = BeautifulSoup(html.content, "lxml")

    cards = bs.select("li.card")
    print(f"Crawling {page}, Total News: {len(cards)}")

    for card in cards:
        try:
            url = card.select_one(".title a").get('href')
            title = card.select_one(".title a").text
            title = re.sub(r'(^\[\S+\] )|(^\S+\s?\S+: )', "", title)
            body = card.select_one(".description~.content").text.replace("\n", "")
            status = card.select_one(".status").text.replace("\n", "")
            content = " ".join(body.splitlines())
            result.append([url, title, content, status])

        except Exception as exp:
            logging.warning("Parsing error : %s", exp)


def start(db_path: str = "src/dataset/tabayyun.db", page: int = 3):
    pages = [f"http://cekfakta.com/page/{page_number}" for page_number in range(1, page)]
    with concurrent.futures.ThreadPoolExecutor(max_workers=20) as executor:
        print("Start concurrent process")
        executor.map(crawl, pages)

    engine = create_engine(f'sqlite:///{db_path}', echo=False)
    df = pd.DataFrame(result, columns=["link", "tittle", "content", "status"])

    for i, _ in enumerate(df.iterrows()):
        try:
            df.iloc[[i]].to_sql('articles', con=engine, if_exists='append', index=False, chunksize=100)
        except IntegrityError as err:
            logging.warning("%s already exist, skip the row!", df.iloc[i]['link'])
            continue


if __name__ == '__main__':
    start("tabayyun.db")



import os
import sys
from functools import lru_cache
from warnings import simplefilter

import pandas as pd
from sklearn.feature_extraction.text import CountVectorizer
from sklearn.metrics.pairwise import cosine_similarity

# ignore all future warnings
simplefilter(action='ignore', category=FutureWarning)
project_dir = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(project_dir)


@lru_cache()
def get_dataset():
    df = pd.read_pickle("tabayyun.pkl")
    print("get_dataset.cache_info : ", get_dataset.cache_info())
    return df


@lru_cache()
def get_vectors(text1, text2):
    vectorizer = CountVectorizer(text1, text2)
    vectorizer.fit([text1, text2])
    return vectorizer.transform([text1, text2]).toarray()


@lru_cache()
def get_cosine_sim(text: str):
    ds = get_dataset()
    status = "ARTIKEL TIDAK DITEMUKAN"
    link = []
    for _, row in ds.iterrows():
        vectors_content = get_vectors(text.lower(), row['content'].lower())
        similarity_content = cosine_similarity(vectors_content)
        vectors_tittle = get_vectors(text.lower(), row['tittle'].lower())
        similarity_tittle = cosine_similarity(vectors_tittle)
        if len(text.split()) > 2:
            if similarity_tittle[0][1] > 0.70 or similarity_content[0][1] > 0.70:
                return {"content": row['content'], "status": row['status'], "link": [row['link']]}

        if text.lower() in row['content'].lower():
            status = "Ditemukan beberapa artikel terkait topik tersebut" \
                if len(set(link)) > 1 else "Ditemukan artikel terkait topik tersebut"
            link.append(f"{row['tittle']} - {row['link']}")

    print("get_cosine_sim.cache_info :", get_cosine_sim.cache_info())
    return {"content": text, "status": status, "link": set(link)}


if __name__ == '__main__':
    str1 = """Terdapat Sanksi Bagi yang Berkendara Malam di Jakarta"""
    print(get_cosine_sim(str1))



# -*- coding: utf-8 -*-
"""
    FS Pipeline library, to create airflow pipelines
    with operators like Spark, Hive etc.,
"""
from setuptools import setup, find_packages

setup(
    name='tabayyun-bot',
    version='1.1.11',
    description='A bot for checking indonesia news and hoaxes',
    long_description=open('README.md').read().strip(),
    author='azzambz',
    author_email='zam.badruzaman@gmail.com',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=['pydantic==1.8.2', 'Flask==2.0.1', 'python-telegram-bot==13.7', 'pandas', 'colorama==0.4.4',
                      'termcolor==1.1.0', 'pyfiglet', 'beautifulsoup4==4.9.3', 'certifi==2020.12.5', 'chardet==4.0.0',
                      'idna==2.10', 'lxml==4.6.2', 'numpy==1.20.1', 'pandas==1.2.2', 'python-dateutil==2.8.1',
                      'pytz==2021.1', 'requests==2.25.1', 'six==1.15.0', 'soupsieve==2.2', 'urllib3==1.26.3',
                      'scikit-learn==0.24.2', 'pyopenssl==20.0.1', 'SQLAlchemy==1.4.20'],
    entry_points={
        'console_scripts': [
            'tabayyun-bot = cli.cli:handle_commands',
        ],
    },
    python_requires='>=3.6',
)
